@@ -44,7 +44,7 @@ PACKAGE_SOURCE_EDIT = os.environ.get(
 PACKAGE_BOOK = os.environ.get('PACKAGE_BOOK', FRICAS_URL + '/book.pdf')
 
 ###################################################################
-copyright = '2007-2020, FriCAS Team'
+copyright = '2007-2023, FriCAS Team'
 author = 'FriCAS Team'
 project = PACKAGE_TARNAME
 release = PACKAGE_VERSION
@@ -80,10 +80,10 @@ extensions = [
 # "aggcat#L1675", i.e. the String that appears in the .rst file as
 # :viewcode:`aggcat#L1675`.
 # Such references are generated by api.spad.
-extlinks = {'viewsource':(PACKAGE_SOURCE_VIEW + '/%s', ''),
-            'viewcode':(PACKAGE_SOURCE_VIEW + '/src/algebra/%s', ''),
-            'editcode':(PACKAGE_SOURCE_EDIT + '/src/algebra/%s', ''),
-            'fricasapi':(FRICAS_URL + '/api/%s', '')
+extlinks = {'viewsource':(PACKAGE_SOURCE_VIEW + '/%s', '%s'),
+            'viewcode':(PACKAGE_SOURCE_VIEW + '/src/algebra/%s', '%s'),
+            'editcode':(PACKAGE_SOURCE_EDIT + '/src/algebra/%s', '%s'),
+            'fricasapi':(FRICAS_URL + '/api/%s', '%s')
            }
 
 # Add any paths that contain templates here, relative to this directory.
@@ -175,7 +175,7 @@ rst_epilog = """
        PACKAGE_NAME, PACKAGE_NAME, PACKAGE_URL)
 
 rst_epilog = rst_epilog + """
-.. _SPAD: http://fricas-wiki.math.uni.wroc.pl/ProgrammingSPAD
+.. _SPAD: http://wiki.fricas.org/ProgrammingSPAD
 """
 
 print('=== PACKAGE_NAME:        ' + PACKAGE_NAME)
