@@ -258,8 +258,6 @@ database.
 
 (defvar |$miss| nil "print out cache misses on getdatabase calls")
 
-(defvar |$do_not_compress_databases| t)
-
    ; note that constructorcategory information need only be kept for
    ; items of type category. this will be fixed in the next iteration
    ; when the need for the various caches are reviewed
@@ -307,34 +305,35 @@ database.
  "call the aldor compiler"
  (#| system::system |#
    obey
-   (concatenate 'string (|getEnv| "FRICAS") "/compiler/bin/aldor "
+   (concatenate 'string |$spadroot| "/compiler/bin/aldor "
     flags " " file)))
 
-(defun resethashtables ()
+(defun resethashtables (display_messages)
  "set all *_hash to clean values. used to clean up core before saving system"
  (setq |$has_category_hash| (make-hash-table :test #'equal))
  (setq |$operation_hash| (make-hash-table))
  (setq |$all_constructors| nil)
  (setq |$compress_vector| nil)
  (setq |$compress_stream_stamp| '(0 . 0))
- (|compressOpen|)
+ (|compressOpen| display_messages)
  (setq |$interp_stream_stamp| '(0 . 0))
- (|interpOpen|)
+ (|interpOpen| display_messages)
  (setq |$operation_stream_stamp| '(0 . 0))
- (|operationOpen|)
+ (|operationOpen| display_messages)
  (setq |$browse_stream_stamp| '(0 . 0))
- (|browseOpen|)
+ (|browseOpen| display_messages)
  (setq |$category_stream_stamp| '(0 . 0))
- (|categoryOpen|) ;note: this depends on constructorform in browse.daase
- (initial-getdatabase)
+ ;note: this depends on constructorform in browse.daase
+ (|categoryOpen| display_messages)
+ (initial-getdatabase display_messages)
  (close |$interp_stream|)
  (close |$operation_stream|)
  (close |$category_stream|)
  (close |$browse_stream|)
-#+:GCL (LISP::gbc t)
+#+:GCL (SI::gbc t)
 )
 
-(defun initial-getdatabase ()
+(defun initial-getdatabase (display_messages)
  "fetch data we want in the saved system"
  (let (hascategory constructormodemapAndoperationalist operation constr)
  (format t "Initial getdatabase~%")
@@ -405,22 +404,27 @@ database.
   |UnaryRecursiveAggregate&| |OrderedSet&| |AbelianGroup&| |Algebra&|
   |Module&| |Ring&| |StringAggregate&| |AbelianMonoid&|
   |ExtensibleLinearAggregate&| |PositiveInteger| |StreamAggregate&|
-  |IndexedString| |IndexedList| |ListAggregate&| |LinearAggregate&|
+  |IndexedString| |ListAggregate&| |LinearAggregate&|
   |Character| |String| |NonNegativeInteger| |SingleInteger|
   |OneDimensionalArrayAggregate&| |FiniteLinearAggregate&| |PrimitiveArray|
   |Integer| |List| |OutputForm|))
  (dolist (con constr)
   (let ((c (concatenate 'string
-             (|getEnv| "FRICAS") "/algebra/"
+             |$spadroot| "/algebra/"
              (string (getdatabase con 'abbreviation)) "." |$lisp_bin_filetype|)))
-    (format t "   preloading ~a.." c)
+    (if display_messages
+        (format t "   preloading ~a.." c))
     (if (probe-file c)
-     (progn
-      (put con 'loaded c)
-      (load c)
-      (format t "loaded.~%"))
-     (format t "skipped.~%"))))
- (format t "~%")))
+        (progn
+            (put con 'loaded c)
+            (load c)
+            (if display_messages
+                (format t "loaded.~%")))
+      (if display_messages
+          (format t "skipped.~%")))))
+ (if display_messages
+     (format t "~%")))
+)
 
 ; format of an entry in interp.daase:
 ;  (constructor-name
@@ -438,13 +442,14 @@ database.
 ;    defaultdomain       -- a short list, for %i
 ;    ancestors           -- used to compute new category updates
 ;  )
-(defun |interpOpen| ()
+(defun |interpOpen| (display_messages)
  "open the interpreter database and hash the keys"
  (let (constructors pos stamp dbstruct)
   (setq |$interp_stream| (open (DaaseName "interp.daase")))
   (setq stamp (read |$interp_stream|))
   (unless (equal stamp |$interp_stream_stamp|)
-   (format t "   Re-reading interp.daase")
+   (if display_messages
+       (format t "   Re-reading interp.daase"))
 
    ; Clean old data
    (do-symbols (symbol)
@@ -483,7 +488,7 @@ database.
 ; system files is only the filename and extension. for user files it
 ; contains the full pathname. when the database is first opened the
 ; sourcefile slot contains system names. the lookup function
-; has to prefix the $spadroot information if the directory-namestring is
+; has to prefix the |$spadroot| information if the directory-namestring is
 ; null (we don't know the real root at database build time).
 ; a object-hash table is set up to look up nrlib and ao information.
 ; this slot is empty until a user does a )library call. we remember
@@ -501,13 +506,14 @@ database.
 ;     predicates
 ; )
 
-(defun |browseOpen| ()
+(defun |browseOpen| (display_messages)
  "open the constructor database and hash the keys"
  (let (constructors pos stamp dbstruct)
   (setq |$browse_stream| (open (DaaseName "browse.daase")))
   (setq stamp (read |$browse_stream|))
   (unless (equal stamp |$browse_stream_stamp|)
-   (format t "   Re-reading browse.daase")
+   (if display_messages
+       (format t "   Re-reading browse.daase"))
    (setq |$browse_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$browse_stream| pos)
@@ -529,13 +535,14 @@ database.
     (setf (database-parents dbstruct) (sixth item))))
   (format t "~&")))
 
-(defun |categoryOpen| ()
+(defun |categoryOpen| (display_messages)
  "open category.daase and hash the keys"
  (let (pos keys stamp)
   (setq |$category_stream| (open (DaaseName "category.daase")))
   (setq stamp (read |$category_stream|))
   (unless (equal stamp |$category_stream_stamp|)
-   (format t "   Re-reading category.daase")
+   (if display_messages
+       (format t "   Re-reading category.daase"))
    (setq |$category_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$category_stream| pos)
@@ -546,13 +553,14 @@ database.
     (setf (gethash (first item) |$has_category_hash|) (second item))))
   (format t "~&")))
 
-(defun |operationOpen| ()
+(defun |operationOpen| (display_messages)
  "read operation database and hash the keys"
  (let (operations pos stamp)
   (setq |$operation_stream| (open (DaaseName "operation.daase")))
   (setq stamp (read |$operation_stream|))
   (unless (equal stamp |$operation_stream_stamp|)
-   (format t "   Re-reading operation.daase")
+   (if display_messages
+       (format t "   Re-reading operation.daase"))
    (setq |$operation_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$operation_stream| pos)
@@ -605,8 +613,6 @@ database.
   (getdatabase constructor 'niladic))
  (format t "~a: ~a~%" 'abbreviation
   (getdatabase constructor 'abbreviation))
- (format t "~a: ~a~%" 'constructor?
-  (getdatabase constructor 'constructor?))
  (format t "~a: ~a~%" 'constructor
   (getdatabase constructor 'constructor))
  (format t "~a: ~a~%" 'defaultdomain
@@ -655,10 +661,9 @@ database.
      (setf (get constructor 'abbreviationfor) nil)))))
 
 (defun getdatabase (constructor key)
- (declare (special $spadroot) (special |$miss|))
+ (declare (special |$spadroot|) (special |$miss|))
  (when (eq |$miss| t) (format t "getdatabase call: ~20a ~a~%" constructor key))
- (let (data table stream ignore struct)
-  (declare (ignore ignore))
+ (let (data table stream struct)
   (when (or (symbolp constructor)
           (and (eq key 'hascategory) (pairp constructor)))
   (case key
@@ -713,9 +718,6 @@ database.
     (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-niladic struct))))
-   (constructor?
-    (when (setq struct (get constructor 'database))
-      (setq data (when (database-operationalist struct) t))))
    (superdomain ; only 2 superdomains in the world
     (case constructor
      (|NonNegativeInteger|
@@ -791,7 +793,7 @@ database.
      (when (and data (string= (directory-namestring data) "")
              (string= (pathname-type data) "spad"))
       (setq data
-       (concatenate 'string $spadroot "/../../src/algebra/" data))))
+       (concatenate 'string |$spadroot| "/../../src/algebra/" data))))
     (asharp?                               ; is this asharp code?
      (if (consp data)
       (setq data (cdr data))
@@ -800,11 +802,11 @@ database.
      (if (consp data)
        (setq data
              (if (string= (directory-namestring (car data)) "")
-                 (concatenate 'string $spadroot "/algebra/" (car data)
+                 (concatenate 'string |$spadroot| "/algebra/" (car data)
                                         "." |$lisp_bin_filetype|)
                (car data)))
       (when (and data (string= (directory-namestring data) ""))
-       (setq data (concatenate 'string $spadroot "/algebra/" data
+       (setq data (concatenate 'string |$spadroot| "/algebra/" data
                                           "." |$lisp_bin_filetype|)))))))
   data))
 
@@ -837,18 +839,18 @@ database.
       (let (nrlibdirs skipasos aos)
 
       (chdir (string dirarg))
-      #-:GCL
+;      #-:GCL
       (setq nrlibdirs (directory "*.NRLIB/index.KAF"))
 
       #| directory in GCL (at least gcl-2.6.8) on Windows is buggy,
       it can not handle pathnames having wildcards in the middle,
       so we need a workaround.  |#
-      #+:GCL
-      (setq nrlibdirs
-           (mapcar #'(lambda (f)
-                          (concatenate 'string (namestring f)
-                                         "/index.KAF"))
-                   (directory "*.NRLIB")))
+;      #+:GCL
+;      (setq nrlibdirs
+;           (mapcar #'(lambda (f)
+;                          (concatenate 'string (namestring f)
+;                                         "/index.KAF"))
+;                   (directory "*.NRLIB")))
 
       (setq asys (directory "*.asy"))
 
@@ -1176,12 +1178,12 @@ database.
 
 (defun DaaseName (name)
  (let (daase filename)
-  (declare (special $spadroot))
+  (declare (special |$spadroot|))
   (if (setq daase (|getEnv| "DAASE"))
    (progn
     (setq filename  (concatenate 'string daase "/algebra/" name))
     (format t "   Using local database ~a.." filename))
-   (setq filename (concatenate 'string $spadroot "/algebra/" name)))
+   (setq filename (concatenate 'string |$spadroot| "/algebra/" name)))
   filename))
 
 ;; The compress database is special. It contains a list of symbols.
@@ -1191,20 +1193,22 @@ database.
 ;; into the compress database. In this way long symbol names become
 ;; short negative numbers.
 
-(defun |compressOpen| ()
+(defun |compressOpen| (display_messages)
  (let (lst stamp pos)
   (setq |$compress_stream|
     (open (DaaseName "compress.daase") :direction :input))
   (setq stamp (read |$compress_stream|))
   (unless (equal stamp |$compress_stream_stamp|)
-   (format t "   Re-reading compress.daase")
+   (if display_messages
+       (format t "   Re-reading compress.daase"))
    (setq |$compress_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$compress_stream| pos)
    (setq lst (read |$compress_stream|))
    (setq |$compress_vector_length| (car lst))
    (setq |$compress_vector|
-     (make-array (car lst) :initial-contents (cdr lst))))))
+     (make-array (car lst) :initial-contents (cdr lst)))))
+   (format t "~&"))
 
 (defun write-compress ()
  (let (compresslist masterpos out)
@@ -1420,7 +1424,7 @@ database.
 
 ;; following needs to happen inside restart since $FRICAS may change
 (defun |createInitializers2| ()
- (let ((asharprootlib (strconc (|getEnv| "FRICAS") "/aldor/lib/")))
+ (let ((asharprootlib (strconc |$spadroot| "/aldor/lib/")))
    (set-file-getter (strconc asharprootlib "runtime"))
    (set-file-getter (strconc asharprootlib "lang"))
    (set-file-getter (strconc asharprootlib "attrib"))
