@@ -141,6 +141,7 @@
                    ((IDENTP V) NIL)
                    ((STRINGP U) (AND (STRINGP V) (string> V U)))
                    ((STRINGP V) NIL)
+                   ((BREAK))
                    ((AND (VECP U) (VECP V))
                     (AND (> (SIZE V) (SIZE U))
                          (DO ((I 0 (1+ I)))
@@ -172,10 +173,8 @@
       ((NULL COMPERAND-1) 'T )
       ((NULL COMPERAND-2) NIL)
       ((VECP COMPERAND-1)
-        (COND
-          ((VECP COMPERAND-2) (LEXVGREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((VECP COMPERAND-2) NIL)
+        (BREAK))
+      ((VECP COMPERAND-2) (BREAK))
       ((stringp COMPERAND-1)
         (COND
           ((stringp COMPERAND-2)
@@ -200,33 +199,9 @@
             (CHAR-GREATERP COMPERAND-1 COMPERAND-2) )
           ('else t)))
       ((CHARACTERP COMPERAND-2) NIL )
-      ((FBPIP COMPERAND-1)
-        (COND
-          ((FBPIP COMPERAND-2)
-            (LEXGREATERP (BPINAME COMPERAND-1) (BPINAME COMPERAND-2)) )
-          ('else t)))
-      ((FBPIP COMPERAND-2) NIL)
+      (BREAK)
       ((> (SXHASH COMPERAND-1) (SXHASH COMPERAND-2)))))
 
-(DEFUN LEXVGREATERP (VECTOR-COMPERAND-1 VECTOR-COMPERAND-2)
-  (declare (simple-vector vector-comperand-1 vector-comperand-2))
-    (PROG ((L1 (length VECTOR-COMPERAND-1))
-           (L2 (length VECTOR-COMPERAND-2))
-           (I -1)
-           T1 T2)
-     (declare (fixnum i l1 l2) )
-  LP  (setq i (1+ i))
-      (COND
-        ((EQL L1 I) (RETURN NIL))
-        ((EQL L2 I) (RETURN 'T)))
-      (COND
-        ((EQUAL
-            (SETQ T1 (svref VECTOR-COMPERAND-1 I))
-            (SETQ T2 (svref VECTOR-COMPERAND-2 I)))
-          (GO LP)))
-      (RETURN (LEXGREATERP T1 T2)) ) )
-
-
 (DEFUN GGREATERP (COMPERAND-1 COMPERAND-2)
     ;;  "Order of types: symbol pair NIL vec string num fbpi other"
     (COND
@@ -251,7 +226,8 @@
       ((VECP COMPERAND-1)
         (COND
           ((VECP COMPERAND-2) (VGREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t)))
+          ('else t))
+      )
       ((VECP COMPERAND-2) NIL)
       ((stringp COMPERAND-1)
         (COND
@@ -271,14 +247,9 @@
             (CHAR> COMPERAND-1 COMPERAND-2) )
           ('else t)))
       ((CHARACTERP COMPERAND-2) NIL )
-      ((FBPIP COMPERAND-1)
-        (COND
-          ((FBPIP COMPERAND-2)
-            (GGREATERP (BPINAME COMPERAND-1) (BPINAME COMPERAND-2)) )
-          ('else t)))
-      ((FBPIP COMPERAND-2) NIL)
       ((> (SXHASH COMPERAND-1) (SXHASH COMPERAND-2)))))
 
+;;; Would like to remove this but is is used in PartialFraction
 (DEFUN VGREATERP (VECTOR-COMPERAND-1 VECTOR-COMPERAND-2)
   (declare (simple-vector vector-comperand-1 vector-comperand-2))
     (PROG ((L1 (length VECTOR-COMPERAND-1))
@@ -704,7 +675,17 @@ This function respects intermediate #\Newline characters and drops
 
 (defun WHOCALLED(n) nil) ;; no way to look n frames up the stack
 
-(defun heapelapsed () 0)
+(defun heapelapsed ()
+  #+:clisp
+  (multiple-value-bind (used room static gc-count gc-space gc-time) (sys::%room)
+    (+ used gc-space))
+  #+:cmu (ext:get-bytes-consed)
+  #+:ecl (si:gc-stats t)
+  #+:openmcl (ccl::total-bytes-allocated)
+  #+:sbcl (sb-ext:get-bytes-consed)
+  #+:lispworks (hcl:total-allocation)
+  #-(or :clisp :cmu :ecl :openmcl :sbcl :lispworks)
+  0)
 
 (defun |goGetTracerHelper| (dn f oname alias options modemap)
     (lambda(&rest l)
