@@ -151,6 +151,7 @@
    (|trace|                          . |interpreter|)
    (|undo|                           . |interpreter|)
    (|what|                           . |interpreter|)
+   (|version|                        . |interpreter|)
  ))
 
 (SETQ |$noParseCommands| '(
@@ -165,6 +166,7 @@
     |suspend|
     |synonym|
     |system|
+    |version|
     ))
 
 (SETQ |$tokenCommands| '(
@@ -231,9 +233,9 @@
        (|startGraphics|    .  "system $FRICAS/lib/viewman &")
        (|stopGraphics|     .  "lisp (|sockSendSignal| 2 15)")
        (|time|       . "set message time")
+       (|storage|    . "set message storage")
        (|type|       . "set message type")
        (|unexpose|   . "set expose drop constructor")
-       (|version|    . "lisp (concat |$build_version| \" compiled at \" |$build_date|)")
        (|wc|         . "what categories")
        (|wd|         . "what domains")
        (|wp|         . "what packages")
@@ -242,35 +244,33 @@
 
 (SETQ |$CommandSynonymAlist| (COPY |$InitialCommandSynonymAlist|))
 
-(DEFPARAMETER |$ConstructorCache| (MAKE_HASHTABLE 'ID))
-(SETQ |$instantRecord| (MAKE_HASHTABLE 'ID))
+(DEFPARAMETER |$ConstructorCache| (MAKE_HASHTABLE 'EQ))
+(SETQ |$instantRecord| (MAKE_HASHTABLE 'EQ))
 (SETQ |$immediateDataSymbol| '|--immediateData--|)
 
 (SETQ |$useIntegerSubdomain| 'T)
 
 ;; See CLAMMED BOOT for defs of following functions
 (SETQ |$clamList| '(
-  (|canCoerce| |hash| UEQUAL |count|)
-  (|canCoerceFrom| |hash| UEQUAL |count|)
-  (|coerceConvertMmSelection| |hash| UEQUAL |count|)
-; (|getModemapsFromDatabase| |hash| UEQUAL |count|)
-; (|getOperationAlistFromLisplib| |hash| UEQUAL |count|)
-  (|isLegitimateMode| |hash| UEQUAL |count|)
-  (|isValidType| |hash| UEQUAL |count|)
-  (|resolveTT|   |hash| UEQUAL |count|)
-  (|selectMms1| |hash| UEQUAL |count|)
-  (|underDomainOf|   |hash| UEQUAL |count|)
-  (|findRetractMms| |hash| UEQUAL |count|)
-  (|getConstantFromDomain|  |hash| UEQUAL |count|)
-  (|interpLookup| |hash| UEQUAL |count|)
-;  (|isSubDomain|   |hash| UEQUAL |count|)
+  (|canCoerce| |hash| EQUAL |count|)
+  (|canCoerceFrom| |hash| EQUAL |count|)
+  (|coerceConvertMmSelection| |hash| EQUAL |count|)
+; (|getModemapsFromDatabase| |hash| EQUAL |count|)
+; (|getOperationAlistFromLisplib| |hash| EQUAL |count|)
+  (|isLegitimateMode| |hash| EQUAL |count|)
+  (|isValidType| |hash| EQUAL |count|)
+  (|resolveTT|   |hash| EQUAL |count|)
+  (|selectMms1| |hash| EQUAL |count|)
+  (|underDomainOf|   |hash| EQUAL |count|)
+  (|findRetractMms| |hash| EQUAL |count|)
+  (|getConstantFromDomain|  |hash| EQUAL |count|)
+  (|interpLookup| |hash| EQUAL |count|)
+;  (|isSubDomain|   |hash| EQUAL |count|)
 ))
 
 ;; the following symbol holds the canonical "failed" value
 (SETQ |$failed| "failed")
 
-(SETQ |$constructorDataTable| NIL)
-
 (SETQ |$univariateDomains| '(
     |UnivariatePolynomial|
     |UnivariateTaylorSeries|
@@ -316,7 +316,7 @@
    |UnionCategory|
       ))
 
-(SETQ |$printStorageIfTrue| NIL) ;; storage info disabled in common lisp
+(SETQ |$printStorageIfTrue| NIL)
 (SETQ |$noEnv| NIL)
 
 (SETQ |$SideEffectFreeFunctionList| '(
@@ -414,7 +414,7 @@
 (SETQ |$Zero| '(|Zero|))
 (SETQ |$One| '(|One|))
 (SETQ |$NonMentionableDomainNames|
-      '($ |Rep| |Record| |Union| |Mapping| |Enumeration|))
+      '(% |Rep| |Record| |Union| |Mapping| |Enumeration|))
 
 ;"  modemap:==  ( <map> (p e) (p e) ... (p e) )  "
 ;"  modemaplist:= ( modemap ... )  "
